==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebScrollStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebScrollStrategyDescription } from "./WebScrollStrategyDescription";
/**
 * @hidden
 */
export let WebScrollStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebScrollStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebScrollStrategyDescriptionMetadata.a == null) {
                WebScrollStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebScrollStrategyDescriptionMetadata.c(WebScrollStrategyDescriptionMetadata.a);
            }
            if (a.j(WebScrollStrategyDescriptionMetadata.a)) {
                return;
            }
            a.y(WebScrollStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ScrollStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebScrollStrategyDescriptionMetadata.b(a);
            a.aa("WebScrollStrategy", () => new WebScrollStrategyDescription());
            a.z("WebScrollStrategy", WebScrollStrategyDescriptionMetadata.a);
        }
    }
    WebScrollStrategyDescriptionMetadata.$t = /*@__PURE__*/ markType(WebScrollStrategyDescriptionMetadata, 'WebScrollStrategyDescriptionMetadata');
    WebScrollStrategyDescriptionMetadata.a = null;
    return WebScrollStrategyDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebScrollStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebScrollStrategyDescription } from "./WebScrollStrategyDescription";
/**
 * @hidden
 */
export let WebScrollStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebScrollStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebScrollStrategyDescriptionMetadata.a == null) {
                WebScrollStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebScrollStrategyDescriptionMetadata.c(WebScrollStrategyDescriptionMetadata.a);
            }
            if (a.k(WebScrollStrategyDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebScrollStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ScrollStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebScrollStrategyDescriptionMetadata.b(a);
            a.ac("WebScrollStrategy", () => new WebScrollStrategyDescription());
            a.ab("WebScrollStrategy", WebScrollStrategyDescriptionMetadata.a);
        }
    }
    WebScrollStrategyDescriptionMetadata.$t = /*@__PURE__*/ markType(WebScrollStrategyDescriptionMetadata, 'WebScrollStrategyDescriptionMetadata');
    WebScrollStrategyDescriptionMetadata.a = null;
    return WebScrollStrategyDescriptionMetadata;
})();
